@@ -2,10 +2,13 @@
 from circus.commands import (   # NOQA
     addwatcher,
     decrproc,
+    dstats,
     get,
+    globaloptions,
     incrproc,
     list,
     listen,
+    listpids,
     numprocesses,
     numwatchers,
     options,
