@@ -6,8 +6,9 @@ import sys
 from circus.stream import FileStream
 from circus import util
 
+
 def watcher_defaults():
- return {
+    return {
         'name': '',
         'cmd': '',
         'args': '',
@@ -19,15 +20,16 @@ def watcher_defaults():
         'uid': None,
         'gid': None,
         'send_hup': False,
-        'times': 2,
-        'within': 1,
+        'flapping_attempts': 2,
+        'flapping_window': 1,
         'retry_in': 7,
         'max_retry': 5,
         'graceful_timeout': 30,
         'rlimits': dict(),
         'stderr_stream': dict(),
         'stdout_stream': dict(),
-        'stream_backend': 'thread'}
+        'stream_backend': 'thread',
+        'priority': 0}
 
 
 class DefaultConfigParser(ConfigParser.ConfigParser):
@@ -107,6 +109,7 @@ def get_config(config_file):
     config['endpoint'] = dget('circus', 'endpoint', 'tcp://127.0.0.1:5555')
     config['pubsub_endpoint'] = dget('circus', 'pubsub_endpoint',
                                      'tcp://127.0.0.1:5556')
+    config['stats_endpoint'] = dget('circus', 'stats_endpoint', None, str)
 
     stream_backend = dget('circus', 'stream_backend', 'thread')
     if stream_backend == 'gevent':
@@ -159,11 +162,15 @@ def get_config(config_file):
                 elif opt == 'send_hup':
                     watcher['send_hup'] = dget(section, 'send_hup', False,
                             bool)
-                elif opt == 'times':
-                    watcher['times'] = dget(section, "times", 2, int)
-                elif opt == 'within':
-                    watcher['within'] = dget(section, "within", 1, int)
-                elif opt == 'retry_ind':
+                elif opt == 'flapping_attempts':
+                    watcher['flapping_attempts'] = dget(section,
+                                                        "flapping_attempts", 2,
+                                                        int)
+                elif opt == 'flapping_window':
+                    watcher['flapping_window'] = dget(section,
+                                                      "flapping_window", 1,
+                                                      int)
+                elif opt == 'retry_in':
                     watcher['retry_in'] = dget(section, "retry_in", 7, int)
                 elif opt == 'max_retry':
                     watcher['max_retry'] = dget(section, "max_retry", 5, int)
@@ -177,6 +184,8 @@ def get_config(config_file):
                 elif opt.startswith('rlimit_'):
                     limit = opt[7:]
                     watcher['rlimits'][limit] = int(val)
+                elif opt == 'priority':
+                    watcher['priority'] = dget(section, "priority", 0, int)
 
             # second pass, parse stream conf
             stdout_conf = watcher.get('stdout_stream', {})
