@@ -16,6 +16,7 @@ import shlex
 
 from psutil import Popen, STATUS_ZOMBIE, STATUS_DEAD, NoSuchProcess
 
+from circus.py3compat import bytestring, string_types
 from circus.util import get_info, to_uid, to_gid, debuglog, get_working_dir
 from circus import logger
 
@@ -118,19 +119,20 @@ class Process(object):
             if self.uid:
                 os.setuid(self.uid)
 
-        logger.debug('cmd: ' + cmd)
+        logger.debug('cmd: ' + bytestring(cmd))
         logger.debug('args: ' + str(args))
 
         if args is not None:
-            if isinstance(args, str):
-                args_ = shlex.split(args)
+            if isinstance(args, string_types):
+                args_ = shlex.split(bytestring(args))
             else:
-                args_ = args[:]
+                args_ = [bytestring(arg) for arg in args]
 
-            args_.insert(0, cmd)
+            args_ = shlex.split(bytestring(cmd)) + args_
         else:
-            args_ = [cmd]
+            args_ = shlex.split(bytestring(cmd))
 
+        logger.debug("process args: %s", args_)
         logger.debug('Running %r' % ' '.join(args_))
 
         self._worker = Popen(args_, cwd=self.working_dir,
