@@ -42,6 +42,32 @@ def run_dummy(test_file):
     return 1
 
 
+class DummyProcess1(object):
+
+    def __init__(self):
+        import signal
+        signal.signal(signal.SIGQUIT, self.handle_quit)
+        signal.signal(signal.SIGTERM, self.handle_quit)
+        signal.signal(signal.SIGINT, self.handle_quit)
+        signal.signal(signal.SIGCHLD, self.handle_chld)
+
+    def handle_quit(self, *args):
+        self.alive = False
+
+    def handle_chld(self, *args):
+        pass
+
+    def run(self):
+        self.alive = True
+        while self.alive:
+            time.sleep(0.1)
+
+
+def run_dummy1():
+    dummy1 = DummyProcess1()
+    dummy1.run()
+
+
 class TestTrainer(TestCircus):
 
     def setUp(self):
@@ -87,6 +113,11 @@ class TestTrainer(TestCircus):
 
         return cmd
 
+    def _get_cmd_args(self):
+        cmd = sys.executable
+        args = ['generic.py', 'circus.tests.test_arbiter.run_dummy1']
+        return cmd, args
+
     def test_add_watcher(self):
         msg = make_message("add", name="test1", cmd=self._get_cmd())
         resp = self.cli.call(msg)
@@ -110,6 +141,47 @@ class TestTrainer(TestCircus):
         resp = self.cli.call(msg)
         self.assertTrue(resp.get('status'), 'error')
 
+    def test_add_watcher4(self):
+        cmd, args = self._get_cmd_args()
+        msg = make_message("add", name="test1", cmd=cmd, args=args)
+        resp = self.cli.call(msg)
+        self.assertEqual(resp.get("status"), "ok")
+
+    def test_add_watcher5(self):
+        cmd, args = self._get_cmd_args()
+        msg = make_message("add", name="test1", cmd=cmd, args=args)
+        resp = self.cli.call(msg)
+        self.assertEqual(resp.get("status"), "ok")
+        resp = self.cli.call(make_message("start", name="test1"))
+        self.assertEqual(resp.get("status"), "ok")
+
+        resp = self.cli.call(make_message("status", name="test1"))
+        self.assertEqual(resp.get("status"), "active")
+
+    def test_add_watcher6(self):
+        cmd, args = self._get_cmd_args()
+        msg = make_message("add", name="test1", cmd=cmd, args=args,
+                start=True)
+        resp = self.cli.call(msg)
+        self.assertEqual(resp.get("status"), "ok")
+
+        resp = self.cli.call(make_message("status", name="test1"))
+        self.assertEqual(resp.get("status"), "active")
+
+    def test_add_watcher7(self):
+        cmd, args = self._get_cmd_args()
+        msg = make_message("add", name="test1", cmd=cmd, args=args,
+                start=True, options={"flapping_window": 100})
+        resp = self.cli.call(msg)
+        self.assertEqual(resp.get("status"), "ok")
+
+        resp = self.cli.call(make_message("status", name="test1"))
+        self.assertEqual(resp.get("status"), "active")
+
+        resp = self.cli.call(make_message("options", name="test1"))
+        options = resp.get('options', {})
+        self.assertEqual(options.get("flapping_window"), 100)
+
     def test_rm_watcher(self):
         msg = make_message("add", name="test1", cmd=self._get_cmd())
         self.cli.call(msg)
@@ -169,3 +241,18 @@ class TestTrainer(TestCircus):
         self.cli.call(make_message("stop", name="test"))
         resp = self.cli.call(make_message("status", name="test"))
         self.assertEqual(resp.get('status'), "stopped")
+
+    def test_stop_watchers3(self):
+        cmd, args = self._get_cmd_args()
+        msg = make_message("add", name="test1", cmd=cmd, args=args)
+        resp = self.cli.call(msg)
+        self.assertEqual(resp.get("status"), "ok")
+        resp = self.cli.call(make_message("start", name="test1"))
+        self.assertEqual(resp.get("status"), "ok")
+
+        self.cli.call(make_message("stop", name="test1"))
+        resp = self.cli.call(make_message("status", name="test1"))
+        self.assertEqual(resp.get('status'), "stopped")
+
+        resp = self.cli.call(make_message("status", name="test"))
+        self.assertEqual(resp.get('status'), "active")
